@@ -37,7 +37,8 @@ sub requires {
 	'LWP::UserAgent'	=> 0,
 	strict			=> 0,
 	'Text::CSV'		=> 0,
-	'URI::Escape'		=> 0,
+#	'URI::Escape'		=> 0,
+	'URI'			=> 0,
 	warnings		=> 0,
 	@extra,
     };
@@ -146,7 +147,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2012 by Thomas R. Wyant, III
+Copyright (C) 2010-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
